@@ -34,10 +34,12 @@ mod tests {
             | Type::Fedora
             | Type::Linux
             | Type::Manjaro
+            | Type::Mariner
             | Type::NixOS
             | Type::openSUSE
             | Type::OracleLinux
             | Type::Pop
+            | Type::Raspbian
             | Type::Redhat
             | Type::RedHatEnterprise
             | Type::Solus
